@@ -212,9 +212,10 @@ class TripleOValidatorList(command.Lister):
         try:
             v_consts.DEFAULT_VALIDATIONS_BASEDIR = constants.\
                 DEFAULT_VALIDATIONS_BASEDIR
-            actions = ValidationActions(constants.ANSIBLE_VALIDATION_DIR,
-                                        parsed_args.group)
-            return actions.list_validations()
+            actions = ValidationActions(
+                validation_path=constants.ANSIBLE_VALIDATION_DIR
+            )
+            return actions.list_validations(parsed_args.group)
         except Exception as e:
             raise RuntimeError(_("Validations listing finished with errors\n"
                                  "Output: {}").format(e))
@@ -266,6 +267,13 @@ class TripleOValidatorRun(command.Command):
             )
         )
 
+        parser.add_argument(
+            '--python-interpreter',
+            action='store',
+            default="/usr/libexec/platform-python",
+            help=_("Python interpreter for Ansible execution. ")
+        )
+
         extra_vars_group = parser.add_mutually_exclusive_group(required=False)
 
         extra_vars_group.add_argument(
@@ -417,7 +425,9 @@ class TripleOValidatorRun(command.Command):
                 validations_dir=constants.ANSIBLE_VALIDATION_DIR,
                 validation_name=parsed_args.validation_name,
                 extra_env_vars=extra_env_vars,
-                quiet=quiet_mode)
+                python_interpreter=parsed_args.python_interpreter,
+                quiet=quiet_mode,
+                ssh_user=parsed_args.ssh_user)
         except RuntimeError as e:
             raise exceptions.CommandError(e)
 
